@@ -142,7 +142,7 @@ class StandardFunction:
         return np.divide(data_vector_1, data_vector_2)
 
     @staticmethod
-    def row_sum(matrix: np.ndarray):
+    def row_sum(matrix: np.ndarray, units):
         """
         :param matrix:
         :return:
@@ -469,7 +469,7 @@ class StandardFunction:
         return np.array([histogram_data]).reshape(-1, 1)
 
     @staticmethod
-    def surface_strain(object_data: dict):
+    def surface_strain(object_data: dict, units):
 
         part_ids = object_data["part_ids"]
         part_data = object_data["part_data"]
